@@ -22,11 +22,14 @@ import datetime
 import hashlib
 import zipfile
 
+from django.core.management.base import BaseCommand
+
 from Iuppiter.Util import run
 from Zephyrus.boilerplate.management.commands import (
     PROJECT_MASHINES_DIR, PROJECT_MASHINES_ZIP, ROOT_DIR_PATH)
+from Zephyrus.boilerplate.management.commands import createLogger
 
-from django.core.management.base import BaseCommand
+logger = createLogger(__name__, "BuildProducts.log")    
 
 class Command(BaseCommand):
 
@@ -55,7 +58,7 @@ class Command(BaseCommand):
             del env['DJANGO_SETTINGS_MODULE']
             cmd = "python manage.py build_templates \"%s\" \"%s\" -o" % (
                     templateDir, dstPath)
-            run(cmd, env=env, shell=True, printCmd=True)
+            run(cmd, env=env, shell=True)
         finally:
             # remove project
             os.chdir(currentPath)
