@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_templates.py 10389 2017-10-22 05:43:34Z Lavender $
+# $Id: build_templates.py 10521 2017-11-19 07:10:05Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-10-22 13:43:34 +0800 (週日, 22 十月 2017) $
-# $Revision: 10389 $
+# $Date: 2017-11-19 15:10:05 +0800 (週日, 19 十一月 2017) $
+# $Revision: 10521 $
 
 import os
 import sys
@@ -60,7 +60,7 @@ class Command(BaseCommand):
 
             # get_template
             error = os.system(
-                "%s manage.py get_template %s" % (sys.executable, tempPath))
+                "%s manage.py get_template \"%s\"" % (sys.executable, tempPath))
             if not error == 0:
                 logger.error(
                     "get_template error code: %d, from template: %s" % 
@@ -69,7 +69,7 @@ class Command(BaseCommand):
 
             # build_boilerplate
             error = os.system(
-                "%s manage.py build_boilerplate2 %s" % 
+                "%s manage.py build_boilerplate2 \"%s\"" % 
                 (sys.executable, TEMPLATES_DIR_PATH))
             if not error == 0:
                 logger.error(
@@ -118,10 +118,10 @@ class Command(BaseCommand):
             # create_zip
             if not options['onlyTemplate']:
                 error = os.system(
-                    "%s manage.py create_zip %s" % (sys.executable, dstPath))
+                    "%s manage.py create_zip \"%s\"" % (sys.executable, dstPath))
             else:
                 error = os.system(
-                    "%s manage.py create_zip %s -o -n %s" % (
+                    "%s manage.py create_zip \"%s\" -o -n \"%s\"" % (
                         sys.executable, dstPath, f))
             if not error == 0:
                 logger.error(
