@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_zip.py 10341 2017-10-03 08:42:24Z Lavender $
+# $Id: create_zip.py 10389 2017-10-22 05:43:34Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-10-03 16:42:24 +0800 (週二, 03 十月 2017) $
-# $Revision: 10341 $
+# $Date: 2017-10-22 13:43:34 +0800 (週日, 22 十月 2017) $
+# $Revision: 10389 $
 
 import os
 import shutil
@@ -70,24 +70,24 @@ class Command(BaseCommand):
 
         logger.info("-----Start copy templates-----")
         for root, dirs, files in os.walk(TEMPLATES_DIR_PATH):
-            for file in files:
-                path = os.path.join(root, file)
-                dst = "./templates/%s" % file
+            for f in files:
+                path = os.path.join(root, f)
+                dst = "./templates/%s" % f
                 logger.info("Zip " + path)
                 zip.write(path, dst)
         
         
         index = len(STATIC_DIR_PATH) + 1
         for root, dirs, files in os.walk(STATIC_DIR_PATH):
-            for file in files:
-                path = os.path.join(root, file)
+            for f in files:
+                path = os.path.join(root, f)
                 
                 dst = "./static/%s" % path[index:]
                 logger.info("Zip " + path)
                 zip.write(path, dst)
         for root, dirs, files in os.walk(FIXTURES_DIR_PATH):
-            for file in files:
-                path = 'fixtures/%s' % file
+            for f in files:
+                path = 'fixtures/%s' % f
                 logger.info("Zip " + path)
                 zip.write(path)
                 
@@ -146,4 +146,4 @@ class Command(BaseCommand):
         if os.path.isfile('./%s.zip' % templateName):
             os.remove('./%s.zip' % templateName)
         
-        logger.info('-----All OK!-----')
\ No newline at end of file
+        logger.info('-----All OK!-----')
